@@ -9,9 +9,9 @@ from typing import List
 
 class TimestreamRecordMulti:
     '''
-    A TimestreamRecord represents a single record that can be loaded into Timestream.
-    TimestreamRecords are immutable (i.e. after their creation they cannot be updated).
-    This immutability is intended to preserve the validity of the TimestreamRecord's
+    A TimestreamRecordMulti represents a single record that can be loaded into Timestream.
+    TimestreamRecordMultis are immutable (i.e. after their creation they cannot be updated).
+    This immutability is intended to preserve the validity of the TimestreamRecordMulti's
     attributes (which are validated on init)
     '''
 
@@ -21,7 +21,7 @@ class TimestreamRecordMulti:
         dimensions: TimestreamDimensions = None,
         mstime: int = None
     ):
-        assert not dimensions or type(dimensions) is TimestreamDimensions, f'Invalid dimensions for TimestreamRecord with type {type(dimensions)}'
+        assert not dimensions or type(dimensions) is TimestreamDimensions, f'Invalid dimensions for TimestreamRecordMulti with type {type(dimensions)}'
         assert not mstime or (type(mstime) is int and mstime > 0), f'Millisecond time must be an integer greater than 0, got {mstime}'
 
         # Immutable fields
@@ -74,7 +74,7 @@ class TimestreamRecordMulti:
         return loadable
 
     def to_dict(self) -> dict:
-        '''to_dict returns a human friendly dictionary representation of this TimestreamRecord'''
+        '''to_dict returns a human friendly dictionary representation of this TimestreamRecordMulti'''
         record_dict = {
             'measure_values': self.__measure_values
         }
@@ -84,5 +84,34 @@ class TimestreamRecordMulti:
         record_dict = {**record_dict, **self.dimensions.to_dict()}
         return record_dict
 
+    def __repr__(self) -> str:
+        return json.dumps(self.to_dict())
+
+class RejectedTimestreamRecordMulti:
+    '''
+    RejectedTimestreamRecordMulti is an immutable class representing a TimestreamRecordMulti that got rejected by Timestream during load.
+    This class carries the error message that Timestream returned when rejecting this record.
+    '''
+
+    def __init__(self, record: TimestreamRecordMulti, error: Exception):
+        assert type(record) is TimestreamRecordMulti
+        assert error is not None
+        self.__record = record
+        self.__error = error
+
+    @property
+    def record(self) -> TimestreamRecordMulti:
+        return self.__record
+
+    @property
+    def error(self) -> Exception:
+        return self.__error
+
+    def to_dict(self) -> dict:
+        return {
+            'record': self.record.to_dict(),
+            'error': str(self.error)
+        }
+
     def __repr__(self) -> str:
         return json.dumps(self.to_dict())
\ No newline at end of file
